惊魂记 (豆瓣)
Description: 惊魂记电影简介和剧情介绍,惊魂记影评、图片、预告片、影讯、论坛、在线购票
Keywords: 惊魂记,Psycho,惊魂记影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.161豆瓣电影Top250

# 惊魂记 Psycho (1960)

导演: 阿尔弗雷德·希区柯克
编剧: 约瑟夫·斯蒂凡诺 / 罗伯特·布洛克
主演: 安东尼·博金斯 / 维拉·迈尔斯 / 约翰·加文 / 珍妮特·利 / 马丁·鲍尔萨姆 / 约翰·麦克因泰 / 西蒙·奥克兰 / 弗兰克·艾伯森 / 帕特里夏·希区柯克 / 沃恩·泰勒 / 卢伦·塔特尔 / 约翰·安德森 / 莫特·米尔斯 / 吉特·卡森 / 维吉尼亚·格雷格 / 阿尔弗雷德·希区柯克 / 珍妮特·诺兰 / 罗伯特·奥斯本 / 海伦·华莱士 / Fletcher Allen / 沃尔特·培根 / 弗朗西斯·德塞尔斯 / 乔治·多克斯塔德 / 乔治·埃尔德雷奇 / 哈珀·弗莱厄蒂 / 萨姆·弗林特 / 弗兰克·基尔蒙德 / 泰德·奈特 / 帕特·麦卡弗里 / 汉斯-乔基姆·默比斯 / 弗雷德·谢威勒
类型: 悬疑 / 惊悚 / 恐怖
制片国家/地区: 美国
语言: 英语
上映日期: 1960-06-16(纽约首映) / 1960-09-08(美国)
片长: 109分钟
又名: 精神病患者 / 触目惊心(港) / 精神病人
IMDb: tt0054215
豆瓣评分
引用
9.0
269824人评价
5星
58.6%
4星
34.7%
3星
6.1%
2星
0.4%
1星
0.2%
好于 99% 悬疑片
好于 99% 惊悚片
想看 看过
评价:
推荐

## 惊魂记的剧情简介 · · · · · ·

年轻的马里恩·克兰（珍妮特·利 饰）在Phoenix工作，深受老板洛厄里（沃恩·泰勒 饰）信任。男友萨姆·卢米斯（约翰·加文 饰）在Fairvale经营一家五金店，因要替亡父还债又要支付前妻赡养费而无力再婚，只能借出差的机会偶尔来与马里恩幽会。马里恩对此感到不满，于是在周五下午趁机携四万美元公款驾车潜逃。可是马里恩的潜逃之路并不顺利：先是在出城的时候被洛厄里目击，周六一大早又被警察怀疑。花了七百美元以旧车换新车之后，马里恩继续忐忑地行驶。入夜后，天降大雨，视线模糊，无法行驶，马里恩只得将车泊入路边的贝茨汽车旅馆投宿。老板诺尔曼（安东尼·珀金斯 饰）十分友善，试图邀请马里恩到家里共进晚餐，可惜被凶恶的母亲粗暴阻止，只得将晚餐端至旅馆客厅。马里恩在客厅一边进餐一边与诺尔曼交谈，终于决定周日返回Phoenix。用餐完毕，马里恩回房沐浴。这时，一个老妇的身影... (展开全部) 年轻的马里恩·克兰（珍妮特·利 饰）在Phoenix工作，深受老板洛厄里（沃恩·泰勒 饰）信任。男友萨姆·卢米斯（约翰·加文 饰）在Fairvale经营一家五金店，因要替亡父还债又要支付前妻赡养费而无力再婚，只能借出差的机会偶尔来与马里恩幽会。马里恩对此感到不满，于是在周五下午趁机携四万美元公款驾车潜逃。可是马里恩的潜逃之路并不顺利：先是在出城的时候被洛厄里目击，周六一大早又被警察怀疑。花了七百美元以旧车换新车之后，马里恩继续忐忑地行驶。入夜后，天降大雨，视线模糊，无法行驶，马里恩只得将车泊入路边的贝茨汽车旅馆投宿。老板诺尔曼（安东尼·珀金斯 饰）十分友善，试图邀请马里恩到家里共进晚餐，可惜被凶恶的母亲粗暴阻止，只得将晚餐端至旅馆客厅。马里恩在客厅一边进餐一边与诺尔曼交谈，终于决定周日返回Phoenix。用餐完毕，马里恩回房沐浴。这时，一个老妇的身影突然出现在卫生间…… ©豆瓣

## 惊魂记的演职员 · · · · · · ( 全部 38 )

- 阿尔弗雷德·希区柯克 导演
- 安东尼·博金斯 饰 Norman Bates
- 维拉·迈尔斯 饰 Lila Crane
- 约翰·加文 饰 Sam Loomis
- 珍妮特·利 饰 Marion Crane
- 马丁·鲍尔萨姆 饰 Det. Milton Arbogast

## 惊魂记的视频和图片 ······ ( 预告片2 | 视频评论1 · 添加 | 图片720 · 添加 )

## 惊魂记的获奖情况 · · · · · · ( 全部 )

- 第33届奥斯卡金像奖
- 最佳导演(提名)
- 阿尔弗雷德·希区柯克

- 第33届奥斯卡金像奖
- 最佳女配角(提名)
- 珍妮特·利

- 第18届金球奖
- 电影类 最佳女配角
- 珍妮特·利

## 喜欢这部电影的人也喜欢 · · · · · ·

  后窗

  迷魂记

  电话谋杀案

  闪灵

  西北偏北

  控方证人

  群鸟

  恐怖游轮

  爱德华大夫

  夺魂索

我要写短评

## 惊魂记的短评 · · · · · · ( 全部 68243 条 )

热门 / 最新 / 好友

### 3524 有用 昏金暗玉 看过 2008-09-18 14:52:42

看这部电影必须回答一个经典的问题：女主角遭到刺杀时，镜头直面花洒，花洒每一条水痕都清晰无误如同肉眼看着一样上镜。请问，摄影机是如何做到的？

### 1584 有用 [已注销] 看过 2008-05-03 12:41:41

且看诺曼的last smile 毛骨悚然！

### 3085 有用 Doublebitch 看过 2011-01-18 17:19:49

人格分裂的鼻祖，试想60年代人们看到这部电影时能有几个不喊牛逼的

### 1769 有用 17950 看过 2010-11-13 23:15:39

神作。全面滿分。如果有任何不被打動的理由，那就是觀眾晚生了50年，受到太多這部電影50年來泛濫的影響，就像一個沒有受過高等教育的英國老婦不會覺得沙劇牛逼一樣。

### 914 有用 同志亦凡人中文站 看过 2014-10-31 17:56:08

剧本和细节真是绝了，对性别的理解更是超前时代。万圣节去看希区柯克就是no zuo no die的节奏，惊恐交加中居然错抓了邻座小哥的手... o(>﹏<)o

> 更多短评 68243条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 惊魂记的影评 · · · · · · ( 全部 518 条 )

热门 / 最新 / 好友
卡列宁的微笑 2007-01-21 00:37:06

## 浅析希区柯克的悬念电影：以《惊魂记》为例

浅析希区柯克的悬念电影：以《惊魂记》为例[1] 一、关于导演：悬念大师的艺术世界[2] 　　 希区柯克是一位独特的导演。他是英国人，1939年二战爆发前夕移居美国，在美国度过了他职业生涯的巅峰时期。1980年，在希区柯克去世前的几个月，英国女王授予他爵士封号。他一生拍过50... (展开)
3382 62 230回应 收起
又又 2011-01-28 23:38:53

## 【译】《惊魂记》中的性别与权力

这篇影评可能有剧透

【译】《惊魂记》中的性别与权力 作者：Matthew Cohen 译者：又又 原文地址：http://web.mit.edu/wgs/prize/mc09.html 希区柯克的经典恐怖片《惊魂记》（1960）不仅是个关于谋杀和精神病的故事，其中也涉及性别与权力的关系。影片一开始就把主人公Marion Crane （Janet Le... (展开)
895 86 56回应 收起
青龙衣 2018-08-06 23:06:00

## Psycho讲的是精神分裂症不是多重人格

这篇影评可能有剧透

最开始看完电影也最直接的想到多重人格，导演似乎想通过心理医生一番推理和“母亲”最后诡谲的心理独白引导观众朝着“母亲人格”犯罪的思路上，但反复推敲片中片尾几个重要片段，不少影迷发现事情并非这么简单——似乎“母亲人格”并非强势到能够杀人？似乎还可能存在第三种“... (展开)
329 51回应 收起
花边内裤 2012-04-03 04:25:42

## 真正的大师希区柯克，意义绝不只在于同类开山

这篇影评可能有剧透

很遗憾一直对希区柯克的作品浅尝辄止，大概是个人受不了那个年代影片的慢节奏和黑白的色调。直至今日重温经典，看完一个多小时还是久久不能平静整个片子所带来的震撼。 的确，如今看了许多同类电影，悬疑犯罪的或者精神分裂的，自以为早已能看穿导演编剧在此类影片中安排的伎俩... (展开)
388 83 57回应 收起
Maverick 2015-02-02 21:38:28

## 《精神病患者》电影剧本

《精神病患者》电影剧本 文/〔美〕约瑟夫·斯蒂法诺 译/林瑞颐 题图：周铮 美国环球公司，1960，109分钟，黑白 制片：谢姆利/希区柯克 原著：罗伯特·布洛奇 导演：阿尔弗雷德·希区柯克（以及索尔·巴斯）（注1） 摄影：约翰·L·洛塞尔 音乐：伯纳德·赫尔曼 主要演员：安... (展开)
159 7回应 收起
圣墟 2017-05-10 09:21:51

## 平行蒙太奇拍摄的典范

从一部惊悚、悬疑、恐怖电影的角度来看，《惊魂记》无疑是成功的，至少在我的眼里它是成功的。 《惊魂记》中浴室谋杀的情节早已成为了电影史上的经典镜头，被后世称为运用平行蒙太奇拍摄的典范。在整个谋杀片段中，尽管连一个刀子插入人体的画面都没有，但是，通过蒙太奇手法的... (展开)
166 25 18回应 收起
泥鳅也是蛇 2015-10-28 17:06:50

## 并非只有血腥才叫暴力

制造悬念，并非保密情节，而是注重心理上的震撼效果，让观众注意力集中到人物命运的转机上，并通过一些精心设计的细节和剪接的画面加以实现。这部被视为西方第一部现代恐怖片，其恐怖来自于人类本身，来自于人性之恶。浴室杀人场面，由78个快速切换得刀，人体，喷头，浴缸等特... (展开)
61 8 3回应 收起
赱馬觀♣ 2012-12-14 10:23:44

## 《惊魂记》编剧约瑟芬·斯蒂法诺访谈

2003年4月，纽约大学电影研究主席理查·阿兰（RA）与《惊魂记》编剧约瑟芬·斯蒂法诺（JS）访谈…… （·走马观花·拙译） RA: 你能谈谈你是如何如何从一个纽约歌曲作家变成好莱坞的剧作家吗？ JS: 我真的认为自己的歌曲创作不错。我出过很多唱片。感觉就好像是爬上一座山... (展开)
34 1 1回应 收起
糖果魔法师。 2017-06-08 16:41:48

## 惊魂记

大师最为著名的作品之一，完美的刻画了一个双重人格以及恋母和性格错乱的精神病杀手的形象，而且对片中女主的刻画也非常传神；画面和音乐的强烈恐怖因素也是电影能够成功的主要因素。 悬念丛生、步步为营、节奏紧凑，简单故事却包裹了深刻内涵，尤其是人物个性转变的塑造令人印... (展开)
22 2 0回应 收起
豆瓣时间 2019-08-19 11:12:53

## 永远的大师：纪念希区柯克诞辰120周年

这篇影评可能有剧透

最近，豆瓣上正开展“希区柯克诞辰120周年”纪念活动。希区柯克作为电影史上最伟大的悬疑大师，开创了一系列用电影语言讲故事的方法，这些方法至今还被无数的影人不断效仿。 希区柯克最擅长的，就是用电影的方式“惊吓”观众，这种惊吓，不是用血腥暴力的画面来刺激观众，而是... (展开)
23 0回应 收起

> 更多影评 518篇

添加新讨论

## 讨论区 · · · · · ·

求网盘资源啊 | 来自阿笨 | 6 回应 | 2022-11-24 16:12:06
有一个点 浴室被害的时候 | 来自tothepast | 2 回应 | 2022-11-20 09:31:36
竟然有人会说恐怖！？ | 来自Raphael | 36 回应 | 2022-11-18 08:23:26
3星 光从剧情和画面呈现的精彩度上我认为本片不配... | 来自MrZongli02 |  | 2022-11-18 08:21:15
b站资源014105贝茨首次穿女装出场笑死我了！ | 来自MrZongli02 |  | 2022-11-17 18:35:18

> 去这部影片的讨论区（全部184条）

## 关于《惊魂记》的问题 · · · · · · ( 全部28个 )

- 侦探是怎么确定女主住在1号房间的？ 2人回答
- 杀人的究竟是“母亲”人格还是“诺曼”人格？ 13人回答

> 全部28个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 单片付费
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 免费观看
- 1905电影网 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 【真实犯罪】—— 真人真事改编案件（世界版1） (狷介有乌青)
- 心理学电影(一句话剧透,不喜勿入) (何学卿)
- 电影学院本科生必看100部 (志国)

## 谁在看这部电影 · · · · · ·

- F
  刚刚 想看
- 氛围辣妹
  7分钟前 想看
- dongbotai1995
  8分钟前 想看

347794人看过 / 175557人想看

订阅惊魂记的评论:
feed: rss 2.0